import React from 'react';
import { ViewStyle, StyleProp, ButtonProps } from 'react-native';
import { Color } from 'csstype';
/**
 * Properties for the {@link CrossButton} component
 * @typedef ICrossButtonProps
 * @type ICrossButtonProps
 */
export interface ICrossButtonProps {
    /**
     * Foreground (icon) color. Default is {@link Colors.CrossBlack}
     */
    color?: Color;
    /**
     * Font-Awesome icon name
     *
     * https://fontawesome.com/icons/
     */
    iconName?: string;
    /**
     * Background color. Default value is {@link Colors.NextButton} if {@link title} was supplied
     */
    backgroundColor?: Color;
    style?: StyleProp<ViewStyle>;
    title?: string;
    /**
     * Size of the icon
     */
    size?: number;
    disabled?: boolean;
    /**
     * Button visual appearence. Default is 'text'
     *
     * https://callstack.github.io/react-native-paper/button.html
     */
    mode?: 'text' | 'outlined' | 'contained';
    /**
     * Optional button styles to apply
     */
    buttonStyle?: ButtonProps;
    onPress?: () => void;
    compact?: boolean;
}
/**
 * A custom button that displays as an Paper Button with icon or just an icon if {@link ICrossButtonProps.title} is not supplied.
 *
 * Remarks: all icons are {@link https://fontawesome.com/v4.7.0/ FontAwesome v4}.
 *
 * Remark: default appearence is "text", see {@link ICrossButtonProps.mode}
 *
 * Properties are {@link ICrossButtonProps}
 */
export declare class CrossButton extends React.Component<ICrossButtonProps> {
    render(): JSX.Element;
}
export default CrossButton;
//# sourceMappingURL=CrossButton.d.ts.map